#! /bin/sh
#+
#
# .. extract_demoandtest.sh:
#
# ======================
# extract_demoandtest.sh
# ======================
#
# SYNOPSIS
# ========
#
# ``extract_demoandtest.sh -i filein -m mode -o fileout``
#
# DESCRIPTION
# ===========
#
# -i  input file
# -o  output file
# -m  mode
#
# ``extract_demoandtest.sh`` extracts demo or test from the file given 
# in argument.
#
# Demo block start with ``%!demo`` and end with a blank line.
#
# Test block start with ``%!test`` and end with a blank line.
#
# EXAMPLES
# ========
#
# To extract demo from :file:`${VARAMMA}/src/geolocation_to_string.m`::
#
#   $ extract_demoandtest.sh -i ${VARAMMA}/src/geolocation_to_string.m -m demo -o geolocation_to_string_demo.m
#
# To extract test from :file:`${VARAMMA}/src/geolocation_to_string.m`::
#
#   $ extract_demoandtest.sh -i ${VARAMMA}/src/geolocation_to_string.m -m test -o geolocation_to_string_test.m
#
# source file::
#   $ cd $VARAMMA/src/+todo+
#
#
# CAUTIONS
# ========
#
# matlab does not provide octave :command:`fail` features
#
# SEE ALSO
# ========
#
# http://www.gnu.org/software/octave/doc/interpreter/Test-and-Demo-Functions.html
#
# makefile
#
# TODO
# ====
#
# check parameters
#
# log
#
# EVOLUTIONS
# ==========
#
# $URL$
#
# - fplod 20110302T161742Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation because of lack of doctest python-like in matlab
#
#   * build from extract_rst.sh
#
#
#-
#
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo " www : no specific posix checking"
   ;;
   *)
     set -o posix
   ;;
esac
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
log=/tmp/$(basename ${command} .sh).log.${log_date}
#
usage=" Usage : ${command} -i filein -m mode -o fileout"
#
minargcount=6
#echo " narg ${#}"
if [ ${#} -lt ${minargcount} ]
then
   echo "eee : not enought arguments"
   echo "${usage}"
   exit 1
fi
#
# default
# n.a.
#
set +u
while [ ! -z "${1}" ]
do
   case ${1} in
      -i)
         filein=${2}
         shift
      ;;
      -o)
         fileout=${2}
         shift
      ;;
      -m)
         mode=${2}
         shift
      ;;
      -h)
         echo "${usage}"
         exit 0
      ;;
      *)
         echo "eee : unknown option ${1}"
         echo "${usage}"
         exit 1
      ;;
   esac
   # next flag
   shift
done
#
set -u
#
# ++ check param
#
case "${mode}" in
   demo)
      awkblockstart="^%!demo$"
      sedblockstart="^%!demo$"
   ;;
   test)
      awkblockstart="^%!test$"
      sedblockstart="^%!test$"
   ;;
   *)
      echo "eee : ${mode} not implemented"
      exit 1
   ;;
esac
#
awkblockend="^$"
sedblockend="^$"
comment="^%! "
#
# just in case suppress \r at the end of lines
tr -d '\r' < ${filein} > /tmp/${$}_0
#
# put demo blocks in one temporary file
cmdawk="awk '/${awkblockstart}/,/${awkblockend}/' /tmp/${$}_0 > /tmp/${$}_1" #++
eval ${cmdawk}
if [ ! -s /tmp/${$}_1 ]
then
  rm /tmp/${$}_0 /tmp/${$}_1
  echo "iii : no ${mode} block in ${filein}"
  exit 1
fi
#
# suppress begin and end of each block
sedcmd="sed -e \"/${sedblockstart}/d\" -e \"/${sedblockend}/d\" /tmp/${$}_1 > /tmp/${$}_2"
eval ${sedcmd}

# suppress comment at the beginning of each line
sedcmd="sed -e \"s/${comment}//\" /tmp/${$}_2 > /tmp/${$}_3"
eval ${sedcmd}
cp /tmp/${$}_3 ${fileout}
#
echo "iii : ${mode} lines of ${filein} are in ${fileout}"
#
# clean
rm /tmp/${$}_0 /tmp/${$}_1 /tmp/${$}_2 /tmp/${$}_3 2> /dev/null
#
# exit
exit 0

