function [PluieTRMM, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = TRMMread(Annee, mois, jour)

%TRMMread lit le fichier NetCDF TRMM
%du jour souhait pour en sortir les
%variables (temps, longitudes et latitudes) ainsi que les donnes de
%l'estimation des prcipitations

%
%+
%
% .. _TRMMread:
%
% ==========
% TRMMread.m
% ==========
%
% .. function:: TRMMread(Annee, Mois, Jour)
%
% DESCRIPTION
% ===========
%
% - Donnes d'entres :
%
%   * Annee (en caractres) : Anne (AAAA) du jour d'tude.
%   * Mois (en caractres) : Numro du mois (MM) du jour d'tude.
%   * Jour (en caractres) : Numro du Jour d'tude (JJ).
%
% - Donnes de sorties :
%
%   * Annee (en caractres) : Anne (AAAA) du jour d'tude.
%   * Mois (en caractres) : Numro du mois (MM) du jour d'tude.
%   * Jour (en caractres) : Numro du Jour d'tude (JJ).
%   * Temps : Variable de temps du fichier NetCDF.
%   * Longitudes : Variable de longitudes dans le domaine [20W 10W].
%   * Latitudes : Variable de latitudes dans le domaine [10N 20N].
%   * PluieTRMM : Donnes brutes de l'estimation des prcipitations dans
%     notre domaine.
%     type double
%     dimension 1 : temps, dimension 2 : lat,  dimension 3 : lon
%
% lecture du fichiers NetCDF TRMM du jour souhait pour en sortir les
% variables (temps, longitudes et latitudes) ainsi que les donnes de
% l'estimation des prcipitations dans notre domaine d'tude (20W-10W et
% 10N-20N)
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
%
% :ref:`data_precipitation_microwave`
%
% :ref:`varamma_startup.m`
%
% :ref:`extract_netcdf_TRMM.sh`
%
% TODO
% ====
%
% domaine restriction on mac and linux
%
% test if existing input file
%
% scale_factor and add_offset  !!
%
% handling of missing values
%
% version in filename is not always 5
%
% test with netcdf_open_available true
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/TRMMread.m $
%
% - fplod 20110830T074359Z cratos (Linux)
%
%   * suppress interactivity
%
%  - fplod 20110606T103853Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%    * try to understand
%    * rename because 3B40read.m is not an authorised filename
%
%  - lelod 20110605
%
%   * Cration from EPSATread.m wich was not validate
%     hard coded input file extracted-3B40RT.2006.5.nc
%
%-
global PROJECT_ID
global netcdf_open_available
%
usage='[PluieTRMM, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = TRMMread(Annee, mois, jour)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%%%%%%%%%%%%%
% Paramtres
%%%%%%%%%%%%%

latmin = 0;
latmax = 20;
lonmin = -20;
lonmax = 0;

% dfinition du repertoire du fichier  lire
%if ispc()
   repertoire = [ PROJECT_ID 'TRMM/3B40/' '/tmp/'];
%else
%   repertoire = [ PROJECT_ID 'TRMM/' Annee '/' Mois '/' ];
%end

% build filename to be read
%Date = ([Annee Mois Jour]);
fullfilename=[repertoire 'extracted-3B40RT.2006.5.nc'];
disp(['iii : opening for reading ', fullfilename]);
clear repertoire

% Ouverture du fichier
if netcdf_open_available
   ncid = netcdf.open(fullfilename, 'NC_NOWRITE');
else
   ncid = netcdf(fullfilename, 'nowrite');
end
clear fullfilename

% Rcupration des variables.
if netcdf_open_available
   Temps = netcdf.getVar(ncid,0);
   Latitudes = netcdf.getVar(ncid,1);
   Longitudes = netcdf.getVar(ncid,2);
else
   Temps = ncid{'time'}(:);
   Latitudes = ncid{'latitude'}(:);
   Longitudes = ncid{'longitude'}(:);
end
%
% Rcupration des donnes de prcipitation et restriction dans  notre domaine d'tude
if netcdf_open_available
   startlat = find(Latitudes >= latmin, 1 );
   countlat = find(Latitudes <= latmax, 1, 'last' ) - startlat + 1;
   startlon = find(Longitudes >= lonmin, 1 );
   countlon = find(Longitudes <= lonmax, 1, 'last' ) - startlon + 1;
   Latitudes = Latitudes(Latitudes >= latmin & Latitudes <= latmax);
   Longitudes = Longitudes(Longitudes >= lonmin & Longitudes <= lonmax);
   clear lonmin
   clear lonmax
   clear latmin
   clear latmax
   %
   % Rcupration des donnes de prcipitation dans ce domaine.
   PluieTRMM = netcdf.getVar(ncid,11,[startlon-1 startlat-1 0],...
    [countlon countlat size(Temps,1)]);
   clear countlat
   clear countlon
   clear startlat
   clear startlon

   % apply scale_factor and add_offset +todo+
   PluieTRMM = double(PluieTRMM);
   %
   % permute to output array with
   % dimension 1 : temps, dimension 2 : lat,  dimension 3 : lon
   PluieTRMM = permute(PluieTRMM,[3 1 2]);

else
   PPT = ncid{'precipitation'}(:,:,:);
   disp(['www : no domaine restrition yet on mac and linux']);

end

if netcdf_open_available
   netcdf.close(ncid);
end
clear ncid
indDate=find(Temps>=datenum(2006,mois,jour) & Temps<datenum(2006,mois,jour+1));
ppt3B(:,:,:)=PPT(indDate,:,:);
tps(:)=Temps(indDate);


%++whos

end

%!demo
%! varamma_startup;
%! more off
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! [PluieTRMM, Temps, Longitudes, Latitudes, Annee, Mois, Jour] = TRMMread(Annee, Mois, Jour);
