function varargout=extract_nc(file,var,varargin)

%EXTRACT_NC Lecture de fichiers .nc

%+
%
% .. _extract_nc.m:
%
% ============
% extract_nc.m
% ============
%
% DESCRIPTION
% ===========
%
% Extraction d''un fichier .nc de variables
% selon les dimensions fournies sous la forme : 
% (nom de la dimension, maximum, minimum ) * nombre de dimension
%
% Retourne chaque dimension extraite suivant les minimum et maximum fournis
% dans l''ordre fourni puis la ou les variables demandees
%
% Retourne les variables demandees corrigees de 'scale_factor' et 'add_offset'
% avec NaN pour les valeurs d''erreur
%
% NB : 
%  - pour extraire une dimension entiere entrer NaN comme bornes min et max
%  - var doit etre un tableau de cellules
%
% EXAMPLES
% ========
%
% ::

%  [tps,lon,lat,extract1,extract2]=extract_nc('nomdufichier',{'data1' 'data2'},
%  ... 'tps',tps_min,tps_max,'lon',lonmin,lonmax,'lat',latmin,latmax);
% 
% voir :ref:`cal_hcl.m` pour exemple d'utilisation
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% Ne fonctionne pas avec des dimensions n'etant pas sous forme de vecteurs
%
% avoid inline comments
%
% EVOLUTIONS
% ==========
%
% $Id: extract_nc.m 326 2011-08-05 14:24:46Z pinsard $
%
% $URL$
%
%-
usage='varargout=extract_nc(file,var,varargin)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%nombre de dimensions
nb_dim=(nargin-2)/3;  

%% Chargement et extraction des dimensions
for i=1:nb_dim
%nom de la dimension   
  dim=varargin{(i-1)*3+1};       
%limite inf de la dimension
  dim_min=varargin{(i-1)*3+2};  
%limite sup de la dimension
  dim_max=varargin{(i-1)*3+3};  

% charge la dimension originale
  var_dim=getnc(file,dim);

% extrait la dimension a la taille demandee et la donne en sortie
  if (isnan(dim_max) & isnan(dim_min))
    ind=[1:length(var_dim)];
  else
    if (isnan(dim_max) & ~isnan(dim_min))
      ind=find(var_dim>=dim_min);
    else
      if (isnan(dim_min) & ~isnan(dim_max))
       ind=find(var_dim<=dim_max);
      else
       ind=find(var_dim>=dim_min & var_dim<=dim_max);
      end
    end
  end
  var_dim=var_dim(ind);
  varargout(i)={var_dim};

% trouve indices min et max de la dimension pour extraction des variables
  ind_min(i)=min(ind);
  ind_max(i)=max(ind);

end

%% Extraction des variables et stokage pour la sortie
for k=1:length(var)
  ext_data=getnc(file,cell2str(var(k)),ind_min,ind_max,-1,-1,2,1,0);
% le dernier 0 du getnc permet de ne pas utiliser
% squeeze par defaut sur la matrice de sortie
% mais besoin d''ajustement qd le singleton est la premiere ou derniere dim
  if ind_min(1)-ind_max(1)==0 | ind_min(end)-ind_max(end)==0
    data=zeros([(ind_max-ind_min)+1]);
    data(:)=ext_data;
  else
    data=ext_data;
  end
  varargout(k+nb_dim)={data};
end
