function [coeffs, r2] = generalscatterplot(data1, data2, nomvar1, nomvar2, infocompl)

%GENERALSCATTERPLOT est une fonction qui trace le diagramme de dispersion 
%entre 2 variables et en sort les coefficient de regression lineaire ainsi 
%que le coefficient de correlation.

%+
%
% =====================
% generalscatterplot.m
% =====================
%
% .. function:: generalscatterplot(data1, data2, nomvar1, nomvar2, infocompl)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * data1 : Matrice de donnees de la premiere variable, qui sera
%     represente sur l'axe des ordonnees du diagramme.
%   * data1 : Matrice de donnees de la seconde variable, qui sera
%     represente sur l'axe des abscisses du diagramme.
%   * nomvar1 (caracteres) : Nom et unite de la premiere variable (pour le
%     titre et axe).
%   * nomvar2 (caracteres) : Nom et unite de la seconde variable (pour le
%     titre et axe).
%   * infocompl (caracteres, facultatif) : Informations complementaires a
%     mettre dans le titre (ex : 'sur une periode de 2 jours').
%
% - Donnees de sorties :
%
%   * coeffs : Vecteur de dimension 1*2 comportant les coefficients a et b 
%     de la regression lineaire y = ax + b.
%   * r2 : Coefficient de correlation.
%
% trace le diagramme de dispersion 
% entre 2 variables et en sort les coefficient de regression lineaire ainsi 
% que le coefficient de correlation.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :func:`MSGanalysiscrossvalidation`
%
% TODO
% ====
%
% improve optional arguments
%
% matlab 7.4 cratos : No allowed line types found. Nothing done.
% octave 3.4 cratos : lsline undefined
%
% describe demo
%
% in demo replace random to make comparison between matlab/octave and machine easier
%
% demo with real data cf MSGanalysiscrossvalidation.m
%
% find a equivalent to matlab refline and lsline
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/generalscatterplot.m $
%
% - fplod 20110830T093209Z cratos (Linux)
%
%   * no call to lsline when octave running
%
% - jaclod 2011-07-29
%
%   * Revision de la documentation et des commentaires.
%   * Changement de nom, 'scatterplot' deja existant.
%
% - jaclod 2011-07-25
%
%   * Creation.
%
%-
global application

usage='[coeffs, r2] = generalscatterplot(data1, data2, nomvar1, nomvar2, infocompl)';
%
if nargin < nargin(mfilename) - 1
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% On passe les donnees sous forme de vecteur.
data1 = reshape(data1,1,[]);
data2 = reshape(data2,1,[]);

% On trace le diagramme.
scatter(data2,data1,5,'filled');

% Ajout d'une droite de regression lineaire selon la methode des moindres
% carrees.
switch application
    case {'matlab'}
        linereg = lsline;
        set(linereg,'color','r','linewidth',2);
    case {'octave'}
        disp(['www : no lsline available using ', application]);
    otherwise
        error('eee : unknown application running');
end

% Recuperation des coefficient de cette droite et du coefficient de
% correlation.
coeffs = polyfit(data2,data1,1);
r2 = corr2(data1, data2);

% Ajout des noms des axes.
xlabel(nomvar2);
ylabel(nomvar1);

% Ajout de titres selon le nombre d'arguments d'entrees.
if nargin == 5;
    title(['Diagramme de dispersion entre les ' nomvar1 ' et les ' nomvar2 ' ' infocompl]);
else
    title(['Diagramme de dispersion entre les ' nomvar1 ' et les ' nomvar2]);
end

end

%!demo
%! close all
%! clear all
%! varamma_startup
%! [coeffs, r2] = generalscatterplot(linspace(1,100*rand(1),100)+rand(1,100),linspace(1,50,100)+10*rand(1)*rand(1,100),'valeurs semi-aleatoires y', 'valeurs semi-aleatoires x', 'pour la demonstration');
