function [ep_cl,grad_tpt]=h_clim(tpt,alt)

%H_CLIM Calcul de la hauteur de la couche limite

%+
%
% .. _h_clim.m:
%
% ========
% h_clim.m
% ========
%
% DESCRIPTION
% ===========
%
% Calcul de la hauteur de la couche limite.
%
% Criteres : 
%  - maximum du gradient de temperature potentielle
%  - hauteur comprise entre 700 et 2500m
%
% Entrees :
% 
% tpt
%    temperature potentielle, tableau 2D (variable,altitude)
% alt
%    altitude en metre, tableau 2D (variable,altitude)
%
% Sorties :
%
% ep_cl
%    hauteur de couche limite en metre, vecteur (variable)
% grad_tpt
%    valeur du gradient de temperature potentielle au sommet de la couche limite, vecteur (variable);
%
% EXAMPLES
% ========
%
% voir :ref:`cal_hcl.m` pour exemple d'utilisation
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id: h_clim.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
%-
usage='[ep_cl,grad_tpt]=h_clim(tpt,alt)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
for n=1:size(tpt,1)

%Calcule difference entre chaque niveau
  dif_tpt=tpt(n,1:size(tpt,2)-1)-tpt(n,2:size(tpt,2));

%Trouve le maximum de la difference
  ind_tpt=min(find(abs(dif_tpt)==max(abs(dif_tpt))));

%Altitudes correspondantes
  alt_tpt=(alt(n,ind_tpt));

%Hauteur couche limite comprise entre 700 et 2500 m
  while (alt_tpt<700 | alt_tpt>2500 | dif_tpt(ind_tpt)>0)
    dif_tpt(ind_tpt)=NaN;
    ind_tpt=min(find(abs(dif_tpt)==nanmax(abs(dif_tpt))));
    alt_tpt=alt(n,ind_tpt);
  end
  ep_cl(n)=alt_tpt;
  grad_tpt(n)=dif_tpt(ind_tpt);

end

