function [result] = histoplot(data,nbclasses,nomvar,infocompl)

%HISTOPLOT est une fonction permettant de tracer la distribution des
%valeurs d'une matrice de donnees en un nombre de classes defini.

%
%+
%
% ============
% histoplot.m
% ============
%
% .. function:: histoplot(data,nbclasses,nomvar,infocompl)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * data : Matrice de donnees de dimensions quelconques.
%   * nbclasses : Nombre de classes de l'histogramme.
%   * nomvar (en caracteres) : Nom de la variable dont on trace la
%     distribution (Pour le titre et l'axe des abscisses).
%   * infocompl (en caracteres, factultatif) : Informations complementaires
%     sur les donnees pour le titre. (Sur la date par exemple 'du 26/07 au
%     ...' par exemple).
%
% Cette fonction permet de tracer la distribution des valeurs d'une
% de donnees en un nombre de classes defini.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% in demo replace random to make comparison between matlab/octave and 
% machine easier
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/histoplot.m $
%
% - fplod 20110804T124311Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add result
%
% - jaclod 2011-07-27
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-25
%
%   * Creation.
%
%-
result=-1;
%
usage='result] = histoplot(data,nbclasses,nomvar,infocompl)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% On place les valeurs sur un seul vecteur;
distribdata = reshape(data,1,[]);
clear data;

% On definit les differentes valeurs centrales de l'histogramme en
% utilisant 'ext', l'etendue de chaque barres.
ext =  (max(distribdata)-min(distribdata)) / nbclasses;
X = min(distribdata) + ext/2 : ext : max(distribdata) - ext/2;

% On trace l'histogramme.
hist(distribdata,X);

% Ajout des noms des axes.
xlabel(nomvar)
ylabel('Nombre')

% Ajout de titres selon les arguments d'entrees.
if nargin == 4;
    title(['Distribution des ' nomvar ' ' infocompl])
else
    title(['Distribution des ' nomvar])
end

result=0;

end

%!demo
%! clear all
%! close all
%! result = histoplot(rand(4,5,5),5,'valeurs aleatoires','dans une matrice 3D pour demonstration');
