function [t,lat,dataconcatenees]=hovmullerlat(dataset,yyyymmddb,yyyymmdde,lon,latmin,latmax)

%+
%
%
% ==============
% hovmullerlat.m
% ==============
%
% .. function:: hovmullerlat(dataset,yyyymmddb,yyyymmdde,lon,latmin,latmax)
%
% DESCRIPTION
% ===========
%
%   :param dataset: dateset EPSAT MSG TRMM
%   :type dataset: string
%   :raise dataset: required
%
%   :param yyyymmddb: date dbut yyyymmdd
%   :type yyyymmddb: double
%   :raise yyyymmddb: required
%
%   :param yyyymmdde: date fin yyyymmdd
%   :type yyyymmdde: double
%   :raise yyyymmdde: required
%
%   :param lon: longitude, W < 0
%   :units lon: deg
%   :type lon: double
%   :raise lon: required
%
%   :param latmin: latitude min, N > 0
%   :units latmin: deg
%   :type latmin: double
%   :raise latmin: required
%
%   :param latmax: latitude max, N > 0
%   :units latmax: deg
%   :type latmax: double
%   :raise latmax: required
%
% If **dateset** is set to ``EPSAT``, `hovmullerlat`` read daily EPSAT files
% :file:`${PROJECT_ID}/EPSAT/yyyy/mm/surf-rr_epsat-sg_multi-sat_010d_30min_yyyymmdd_v*.nc`
% between **yyyymmddb** and **yyyymmdde**
%
% If **dateset** is set to ``MSG``, `hovmullerlat`` read daily MSG files
% :file:`${PROJECT_ID}/MSG/yyyy/mm/msg-tb108-yyyy-mm-dd_15min.nc`
% between **yyyymmddb** and **yyyymmdde**
%
% If **dateset** is set to ``TRMM``, `hovmullerlat`` read daily TRMM files
% :file:`${PROJECT_ID}/TRMM/3B40/yyyy/mm/3B40RT.yyyymmdd.5.nc`
% between **yyyymmddb** and **yyyymmdde**
%
% It plot an hovmller diagram between **latmin** and **latmax** for
% the constant longitude **lon**.
%
% EXAMPLES
% ========
%
% To plot an hovmller diagram of EPSAT between 20060801 and 20060802:
%
% see demo 1
%
% To plot an hovmller diagram of MSG between 20060801 and 20060802:
%
% see demo 2
%
% To plot an hovmller diagram of TRMM between 20060801 and 20060802:
%
% see demo 3
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
% :ref:`data_epsat`
%
% :ref:`varamma_startup.m`
%
% use :
% :func:`EPSATread`
% :func:`MSGread`
% :func:`TRMMread`
%
% TODO
% ====
%
% scientific check : EPSAT demo all blue (0), TRMM blue and < 0
%
% if lon given in arg is not exactly a longitude step of original data file, 
% no data will be output from MSGread or EPSATread. 
% this is the case of -15 not found in EPSAT data; -15.05 exists
%
% test on more than one day
%
% externalize read
%
% don't to how to initialize ficlist because of variable length
% according to PROJECT_ID value
%
% save figure
%
% get rid of mlint output
%
% status de retour
%
% split reading and calculate and plot
%
% check argument
%
% understand this line ::
%
%   dataconcatenees(find(dataconcatenees == 655.35))=NaN;
%
% missing value is  DATA:missing_value = 32767s and they are
% supposed to be set to NaN by MSGread now (20110607)
%
% do we need to build filename here ? no so sure !!
%
% EVOLUTIONS
% ==========
%
% $Id: hovmullerlat.m 326 2011-08-05 14:24:46Z pinsard $
%
% $URL$
%
% - fplod 20110609T132558Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * introduce TRMM dataset
%   * force lonmin lonmax for TRMM dataset (see pb selection of data in read)
%
% - fplod 20110609T124630Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * no more dimension pb for MSG one day demo
%   * lat/lon domaine reduction is now done by reading module
%   * force lonmin lonmax for EPSAT dataset (see pb selection of data in EPSATread/MSGread)
%
% - fplod 20110609T095307Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add dataset parameter
%   * Temps is now julian date
%   * remove unused calculation of "nb de pixels froids"
%   * time is a reserved word
%   * introduce EPSAT dataset
%
% - pinsard 2011-06-08T15:43:37Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * new arg for MSGread
%
% - fplod 20110607T154319Z cratos.locean-ipsl.upmc.fr (Linux)
%
%   * correction for nbfic computation (was always not null)
%
% - fplod 20110607T094651Z cratos.locean-ipsl.upmc.fr (Linux)
%
%   * make it work with octave 3.4.0 : explicit num2str format for date
%     conversion, call for datetick
%   * correction for more than one day
%
% - pinsard 2011-06-07T07:11:27Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * example move to demo
%   * indentation
%   * replace datedebut parameter by yyyymmddb, replace datefin parameter by yyyymmdde
%   * fix for path of MSG files
%   * use of netcdf.open on climserv
%   * loop on yime like in evolution_msg.m
%   * usage of MSGread
%
%   nb : seems to be ok on climserv
%
% - pinsard 2011-05-26T07:52:18Z loholt1.ipsl.polytechnique.fr
%
%   * image is a function (reserve word)
%
% - fplod 20110224T091457Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add a missing end statement
%
% - fplod 20110121T134332Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * complement on header
%
% - fplod 20100608T124102Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * no more datetick if running octave 3.0.2
%
%   * make it work running with matlab 7.4
%     now ::
%
%       Value must be a column or row vector.
%
% - fplod 20100604T092417Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * minimize mlint output
%
% - fplod 20100604T083004Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add usage of varamma_startup : no more chemin parameter, VARAMMA_ID value
%     used instead
%
% - fplod 20100526T122950Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix error: octcdf: indexes must be contiguous
%
% - fplod 20100525T143201Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * rename to hovmullerlat.m to avoid message like ::
%
%      warning: function name \`hovmullerlat\' does not agree with function file name \`/.autofs/home/fplod/incas/varamma/varamma_ws/src/hovmuller.m\'
%
%   * add example (not ok)
%
% - fplod 20100521T150917Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * minimal header
%
% - lelod 20100521
%
%   * creation
%-
global application;
global application_version;
global netcdf_open_available
global PROJECT_ID;
%
usage='[t,lat,dataconcatenees]=hovmullerlat(dataset,yyyymmddb,yyyymmdde,lon,latmin,latmax)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('dataset');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg dataset ' arg_info.class]);
   whos dataset
   error(usage);
end
clear arg_info
%
switch dataset
   case {'EPSAT'}
   case {'MSG'}
   case {'TRMM'}
   otherwise
      error(['eee : unknown dataset ' dataset])
end
%
arg_info=whos('yyyymmddb');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg yyyymmddb ' arg_info.class]);
   whos yyyymmddb
   error(usage);
end
clear arg_info
%
arg_info=whos('yyyymmdde');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg yyyymmdde ' arg_info.class]);
   whos yyyymmddb
   error(usage);
end
clear arg_info
%
datenum_current=datenum(num2str(yyyymmddb,'%8.8d'),'yyyymmdd');
datenum_end=datenum(num2str(yyyymmdde,'%8.8d'),'yyyymmdd');
addtodate_f='day';
addtodate_q=1;
nb_fich_max=999;
% ++ don't to how to initialze because of cariable lengtgh according to PROJECT_ID value
% ++ficlist=repmat('z',nb_fich_max,1);
%++whos ficlist
yyyy_slist=repmat('9999',nb_fich_max,1);
mm_slist=repmat('99',nb_fich_max,1);
dd_slist=repmat('99',nb_fich_max,1);
ifich=0;
% liste des fichiers sur priode choisie
while datenum_current < datenum_end
    disp(['iii : looking for ', datestr(datenum_current,'yyyymmdd')]);
    yyyy_s=datestr(datenum_current,'yyyy');
    mm_s=datestr(datenum_current,'mm');
    dd_s=datestr(datenum_current,'dd');
    switch dataset
        case {'EPSAT'}
            filename=['surf-rr_epsat-sg_multi-sat_010d_30min_' yyyy_s mm_s dd_s '_v3.1-02c.nc'];
            fullfilename=[PROJECT_ID 'EPSAT/' yyyy_s '/' mm_s '/' filename];
        case {'MSG'}
            filename=['msg-tb108_' yyyy_s '-' mm_s '-' dd_s '_15min.nc'];
            fullfilename=[PROJECT_ID 'MSG/' yyyy_s '/' mm_s '/' filename];
        case {'TRMM'}
            trmm_version='5';
            filename=['3B40RT.' yyyy_s mm_s dd_s '.' trmm_version '.nc'];
            fullfilename=[PROJECT_ID 'TRMM/' '3B40/' yyyy_s '/' mm_s '/' filename];
        otherwise
            error(['eee : unknown dataset ' dataset])
    end
    if (exist(fullfilename))
       ifich=ifich+1;
       ficlist(ifich,:)=fullfilename;
       yyyy_slist(ifich,:)=yyyy_s;
       mm_slist(ifich,:)=mm_s;
       dd_slist(ifich,:)=dd_s;
       disp(['iii : data found in ', fullfilename]);
    else
       disp(['iii : no fullfilename ', fullfilename]);
    end
    % next step
    datenum_current=addtodate(datenum_current,addtodate_q, addtodate_f);
    clear yyyy_s
    clear mm_s
    clear dd_s
    clear filename
    clear fullfilename
end
clear datenum_current
clear datenum_end
%
% test if at least one file
nbfic=ifich;
if (nbfic == 0)
   error(['eee : no files found during [' num2str(yyyymmddb,'%6.6d') ',' num2str(yyyymmdde,'%6.6d') '[']);
end

timeconcatene=[];
dataconcatenees=[];
%
lonmax=lon;
lonmin=lon;
%
for ijour=1:nbfic
   switch dataset
       case {'EPSAT'}
           lonmax=lon+0.1;
           lonmin=lon;
           disp(['www : lonmin and lonmax forced to ', num2str(lonmin) ' ' num2str(lonmax)])
           [data, my_time, longitude, latitude, yyyy_s, mm_s, dd_s] = EPSATread(yyyy_slist(ijour,:), mm_slist(ijour,:), dd_slist(ijour,:),lonmin, lonmax, latmin, latmax);
           %++ pour debug en attandat extarnalisation de EPSATread mais pas ok
           % index_simulation=uint8(2);
           %[longitude, latitude, my_time, datestr_value, data] = simul_epsat(index_simulation);
       case {'MSG'}
           [data, my_time, longitude, latitude, yyyy_s, mm_s, dd_s] = MSGread(yyyy_slist(ijour,:), mm_slist(ijour,:), dd_slist(ijour,:),lonmin, lonmax, latmin, latmax);
           %++ pour debug en attandat extarnalisation de MSGread mais pas ok
           %  index_simulation=uint8(3);
           % [longitude, latitude, my_time, datestr_value, data] = simul_msg(index_simulation);
       case {'TRMM'}
           lonmax=lon+0.2;
           lonmin=lon;
           disp(['www : lonmin and lonmax forced to ', num2str(lonmin) ' ' num2str(lonmax)])
           [data, my_time, longitude, latitude, yyyy_s, mm_s, dd_s] = TRMMread(yyyy_slist(ijour,:), mm_slist(ijour,:), dd_slist(ijour,:),lonmin, lonmax, latmin, latmax);
       otherwise
           error(['eee : unknown dataset ' dataset])
   end
   dataconcatenees=[dataconcatenees; data];
   timeconcatene=[timeconcatene; my_time];
end

switch dataset
    case {'EPSAT'}
    case {'MSG'}
        dataconcatenees(find(dataconcatenees == 655.35))=NaN;
    case {'TRMM'}
    otherwise
        error(['eee : unknown dataset ' dataset])
end
[t,lat]=meshgrid(timeconcatene,latitude);
my_image=permute(dataconcatenees,[3 1 2]);
switch application
   case {'matlab'}
      imagesc(timeconcatene,latitude,my_image);
   case {'octave'}
      imagesc(t,lat,my_image);
   otherwise
      error('unknown application running');
end
shading flat;
xlabel('time');
ylabel('latitude');
xlim([min(timeconcatene) max(timeconcatene)])
set(gca,'Ydir','reverse')
switch application
  case {'matlab'}
     datetick('x',6);
  case {'octave'}
     switch application_version
        case {'3.0.2'}
           disp(['no datetick available using ', application , application_version]);
        case {'3.4.0'}
           datetick('x',6);
        otherwise
           error(['unknown application version running ', application , application_version]);
     end
  otherwise
     error('unknown application running');
end
colorbar('SouthOutside');

end

%!demo
%! % To plot an hovmller diagram of EPSAT between 20060801 and 20060802::
%! clear all
%! close all
%! varamma_startup
%! more off
%! dataset='EPSAT';
%! lon=-15;
%! latmin=10;
%! latmax=15;
%! yyyymmddb=20060801;
%! yyyymmdde=20060802;
%! [t,lat,dataconcatenees]=hovmullerlat(dataset,yyyymmddb,yyyymmdde,lon,latmin,latmax);

%!demo
%! % To plot an hovmller diagram of MSG between 20060801 and 20060802::
%! clear all
%! close all
%! varamma_startup
%! more off
%! dataset = 'MSG';
%! lon = -15;
%! latmin = 10;
%! latmax = 15;
%! yyyymmddb = 20060801;
%! yyyymmdde = 20060802;
%! [t,lat,dataconcatenees] = hovmullerlat(dataset,yyyymmddb,yyyymmdde,lon,latmin,latmax);

%!demo
%! % To plot an hovmller diagram of TRMM between 20060801 and 20060802::
%! clear all
%! close all
%! varamma_startup
%! more off
%! dataset = 'TRMM';
%! lon = -15;
%! latmin = 10;
%! latmax = 15;
%! yyyymmddb = 20060801;
%! yyyymmdde = 20060802;
%! [t,lat,dataconcatenees] = hovmullerlat(dataset,yyyymmddb,yyyymmdde,lon,latmin,latmax);
