;+
;
; =====================
; read_regular_grid.pro
; =====================
;
; .. function:: read_regular_grid(file_ncdf)
;
; DESCRIPTION
; ===========
;
; Lecture de la grille rgulire
;
;    :param file_ncdf:  file to be read
;    :type file_ncdf: string
;    :raise file_ncdf: required
;
; EXAMPLES
; ========
;
; ::
;
;    file_ncdf=project_id_env + '/MSG/2006/08/01/200608010000_msg-tb108_map_15min.nc'
;    reggrid=read_regular_grid(file_ncdf)
;    help, reggrid,/structure
;   ** Structure <154a3bf8>, 2 tags, length=29696, data length=29696, refs=1:
;      LON             DOUBLE    Array[1856]
;      LAT             DOUBLE    Array[1856]
;
; or::
;
;    file_ncdf=project_id_env + '/MSG/2006/06/01/msg_IR108_20060601.nc'
;    reggrid=read_regular_grid(file_ncdf)
;    help, reggrid,/structure
;   ** Structure <1548f7d8>, 2 tags, length=6008, data length=6008, refs=1:
;      LON             FLOAT     Array[834]
;      LAT             FLOAT     Array[668]
;
; SEE ALSO
; ========
;
; :ref:`data_msg`, :ref:`data_amsu`
;
; Called by :ref:`amsu2ncdf.pro`
;
; TODO
; ====
;
; return on error 
;
; coding rules
;
; complete description
;
; EVOLUTIONS
; ==========
;
; $Id: read_regular_grid.pro 215 2011-04-26 10:33:10Z pinsard $
;
; $URL$
;
; - pinsard 2011-08-10T14:41:52Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * complete description
;   * make it work with project_id_env + '/MSG/2006/06/01/msg_IR108_20060601.nc'
;
; - fplod 20110121T150223Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * split of amsu2ncdf.pro
;
; - fplod 20100701T130054Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
function read_regular_grid, file_ncdf

filename=file_basename(file_ncdf)

; Open the NetCDF file:
id = NCDF_OPEN(file_ncdf,/nowrite)

CASE filename OF
    '200608010000_msg-tb108_map_15min.nc' : BEGIN
         lon_long_name = 'LONGITUDE'
         lat_long_name = 'LONGITUDE'

    END
    'msg_IR108_20060601.nc' : BEGIN
         lon_long_name = 'longitude'
         lat_long_name = 'latitude'
    END
    ELSE: BEGIN
          msg = 'eee : ' + file_ncdf + ' not implemented'
          ras = report(msg)
    END
ENDCASE

; Get the variable ID for the longitude:
lonid = NCDF_VARID(id, lon_long_name)

; Get the variable ID for the Latitude:
latid = NCDF_VARID(id, lat_long_name)

; Get the full longitude array:
NCDF_VARGET, id, lonid, lon

; Get the full latitude array:
NCDF_VARGET, id, latid, lat

; Close the NetCDF file:
NCDF_CLOSE, id

; Retour des valeurs
return, { $
    lon : lon, $
    lat : lat $
}

end
