#! /bin/sh
#+
#
# .. program:: run_cresamsu.sh
#
# .. _run_cresamsu.sh:
#
# ===============
# run_cresamsu.sh
# ===============
#
# SYNOPSIS
# ========
#
# ::
#
#  run_cresamsu.sh -b yyyymmdd -e yyyymmdd -lonmin lonmin -lonmax lonmax -latmin latmin -latmax latmax -numch numch -temp temp -rtemp rtemp -rhdeg rhdeg
#
# DESCRIPTION
# ===========
#
# .. option:: -b beginning date <yyyymmdd>
# .. option:: -e end date <yyyymmdd>
# .. option:: -lonmin <lonmin>
# .. option:: -lonmax <lonmax>
# .. option:: -latmin <latmin>
# .. option:: -latmax <latmax>
# .. option:: -numch <channel>
# .. option:: -temp <temp>
# .. option:: -rtemp <rtemp>
# .. option:: -rhdeg <rhdeg>
#
# lancement de :ref:`cresamsu.sh` en batch
#
# Job stderr is in the working directory :file:`run_cresamsu.e{xxxxx}`, stdout is in :file:`run_cresamsu.o{xxxxx}`
#
# Log file of :ref:`cresamsu.sh` is written on
# :file:`${PROJECT_LOG}/cresamsu.log.{YYYYMMDDTHHMMSSZ}`
#
# SEE ALSO
# ========
#
# :ref:`varamma_profile.sh`
# :ref:`cresamsu.sh`
#
# http://climserv.ipsl.polytechnique.fr/fr/utilisation-du-cluster-climserv/le-cluster-de-calcul-2.html
#
# EXAMPLES
# ========
#
# To submit with qsub::
# 
#   run_cresamsu.sh -b 20060813 -e 20060814 -lonmin -25 -lonmax 25 -latmin -5 -latmax 20 -numch a5 -temp 'm' -rtemp 1. -rhdeg .5
#
# The job id will be written on the screen.
#   
# To check job status::
#
#   qstat {jobid}
#
# When the job is done, look at log file of cresamsu.sh::
#
#   tlogd.sh cresamsu
#
# TODO
# ====
#
# destruction de ${PROJECT_LOG}/job_run_cresamsu.sh  : quand ? pas ici car le job
# en question n'est pas fini
#
# calcul du temps estim total en fonction du nb de jours demands plutot 
# qu'un mechant 10:00:00 en dur
#
# check param or fusion with cresamsu.sh
#
# introduire methode comme dans run_modmarin pour batch cratos (pas de PBS !)
# 
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - fplod 20120430
#
#   * creation
#
#-
#
system=$(uname)
case "${system}" in
   AIX|IRIX64)
     echo "${command} : www : no specific posix checking"
     date_cmd=date
   ;;
   Darwin)
     set -o posix
     date_cmd=gdate
   ;;
   Linux)
     set -o posix
     date_cmd=date
   ;;
   *)
    set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} [-f] -b yyyymmdd -e yyyymmdd -lonmin lonmin -lonmax lonmax -latmin latmin -latmax latmax -numch numch -temp temp -rtemp rtemp -rhdeg rhdeg"
#
hostname=$(hostname)
#
while [ ${#} -gt 0 ]
do
   case ${1} in
     -b)
        # first date to get
        yyyymmddb=${2}
        shift
     ;;
     -e)
        # last date to get
        yyyymmdde=${2}
        shift
     ;;
     -lonmin)
        lonmin=${2}
        shift
     ;;
     -lonmax)
        lonmax=${2}
        shift
     ;; 
     -latmin)
        latmin=${2}
        shift
     ;;
     -latmax)
        latmax=${2}
        shift
     ;;
     -numch)
        numch=${2}
        shift
     ;;
     -temp)
        temp=${2}
        shift
     ;;
     -rtemp)
        rtemp=${2}
        shift
     ;;
     -rhdeg)
        rhdeg=${2}
        shift
     ;;
     -f)
        force=1
     ;;
     -h)
        echo "${usage}"
        exit 0
     ;;
     *)
        # other choice
        echo "${command} : eee : unknown option ${1}"
        echo "${usage}"
        exit 1
     ;;
   esac
   # next flag
   shift
done
unset usage
#
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
echo "IDL_CMD=${IDL_CMD}" 1>> ${log}
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "yyyymmddb=${yyyymmddb}" 1>> ${log}
echo "yyyymmdde=${yyyymmdde}" 1>> ${log}
echo "lonmin=${lonmin}" 1>> ${log}
echo "lonmax=${lonmax}" 1>> ${log}
echo "latmin=${latmin}" 1>> ${log}
echo "latmax=${latmax}" 1>> ${log}
echo "numch=${numch}"  1>> ${log}
echo "temp=${temp}"  1>> ${log}
echo "rtemp=${rtemp}"  1>> ${log}
echo "rhdeg=${rhdeg}"  1>> ${log}
echo "" 1>> ${log}

# ++ faire plus malin que comme nom de job
jobname=$(basename ${command} .sh)
jobfile=${PROJECT_LOG}/job_${jobname}.${log_date}.sh
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
#
# build script to be submitted
cat > ${jobfile} << EOF
#!/bin/sh
#PBS -S /bin/sh
#PBS -N ${jobname}
#PBS -j eo
#PBS -o ${log}
#
. ${PROJECT}/src/varamma_profile.sh -d ${PROJECT}/ -i ${PROJECT_ID} -o ${PROJECT_OD} -t ${PROJECT_LOG} -s ${SAXO_DIR} -idl_cmd ${IDL_CMD}
time cresamsu.sh -b ${yyyymmddb} -e ${yyyymmdde} -lonmin ${lonmin} -lonmax ${lonmax} -latmin ${latmin} -latmax ${latmax} -numch ${numch} -temp ${temp} -rtemp ${rtemp} -rhdeg ${rhdeg}
EOF
#
echo "submitted job ${jobfile} :" >> ${log} 2>&1
cat ${jobfile} >> ${log} 2>&1
# submit job
qsub -l walltime=10:00:00 ${jobfile}
#
# end
unset log_date
exit 0
