; docformat = 'rst'
;+
;
; .. _ssminuage.pro:
;
; =============
; ssminuage.pro
; =============
;
; DESCRIPTION
; ===========
;
; Programme d'analyse des nuages SSMI de FASTEX
; (parametres geophysiques restitues (WV, LW, US)
;
; EXAMPLES
; ========
;
; ::
;
;   ssminuage
;
; SEE ALSO
; ========
;
; :ref:`data_msg`
;
; TODO
; ====
;
; - pinsard 2011-08-17T15:36:34Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * new terminology
;
; - fplod 20100614T102440Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * parameter time selection of data
;
; - fplod 20100611T110206Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * improve graph to see input data and detected clouds
;   * test if ncloud_max too small
;
; - fplod 20100611T090103Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * make it work with more complex fake data
;   * externalize ssmi specificities
;   * handle MSG/AMSU data
;   * rewrote in matlab/octave
;   * introduce a time dimension
;   * build usefull output : add geolocation (may be two outputs will
;     be necessary : one summary and one NetCDF file
;   * suppress goto
;
;     - around labnu : why not a loop
;
;   * si un jour on retravaille avec SSMI
;     Premier nettoyage: si moins de 20 lignes dans l'image, eliminer l'image,
;     sinon traitement
;
;
; EVOLUTIONS
; ==========
;
; $Id: ssminuage.pro 215 2011-04-26 10:33:10Z pinsard $
;
; - fplod 20110426T075706Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   $ usage of PROJECT*
;   $ add pro
;
; - fplod 20100614T102342Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * test with 1st MSG file msg-tb108_2006-08-01_15min.nc
;   * test with amsubch5-noaa17_20060801-000722_afratl_Nadir.nc
;   * add headr in output ascii data
;
; - fplod 20100611T131222Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * threshold depend on dataset
;   * get rid of hard coded dimension : 100 was the maximum of clouds 
;     detected : too big, too small ?
;     depend on dataset ? replace by ncloud_max and initialize before
;     detection part
;   * move time information decoding after reading or initializing fake data
;     because independant of cloud detection
;   * 2 clouds in fake dataset
;   * loop to write each cloud informations
;
; - fplod 20100611T102258Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * get rid of reading loop
;   * suppress some goto
;   * explicit IF THEN structure
;   * localize output (open, write, close) at the end
;   * get rid of some hard coded dimensions
;   * introduce graph to see input data and detected clouds
;   * indent code
;
; - fplod 20100611T093909Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * equivalence PV_PWAVE IDL :
;
;     - avg / mean
;     - stdev /stddev
;
;   * minimal modif. to run with fake data.
;
; ATTENTION : CHANGEMENTS IMPORTANTS:
; ===================================
;
; - lelod 13/07/2010 skylla
;
;   * revision de la detection des nuages : adaptation a MSG
;     (Tb < threshold) donc maintenant incompatible avec LW SSMI!!!!!
;   * detection faite avec MSG, pas AMSU (en raison des "trous" dans l'orbite)
;   * remplacement des commandes de trace CONTOUR par commande PLT SAXO
;   * enchainement des lectures AMSU et MSG, pour calcul de la TB
;     moyenne AMSU dans les nuages donc suppression des "goto" entre les deux
;
;-
PRO ssminuage
;
@cm_project
; uncomment following line to work with MSG datafiles
;dataset='MSG'
; uncomment following line to work with AMSU datafiles
;dataset='AMSU'
dataset='FAKE'
CASE dataset OF

   'AMSU': BEGIN
 ;     name='amsubch5-noaa17_20060801-000722_afratl_Nadir.nc'
      path=project_id_env+'/AMSU'+'/2006'+'/08' + '/'
      name='amsubch5-noaa15_20060813-064214_afratl_Nadir.nc'
      file=path+name
      initncdf, file, xaxisname = 'longitude', yaxisname = 'latitude'
      lon1=-25 & lon2=25 & lat1=-5 & lat2=20
      domdef,lon1,lon2,lat1,lat2
      data=read_ncdf('tbch5b',0,0,/timestep,timevar='time',file = file)
      ; ++ close
      date=strmid(name,16,8)
      heure=strmid(name,25,6)
      tbamsu=data.arr
      seuil=270.
      s=size(wl,/DIMENSIONS)
      ni=s[0]
      ll=s[1]
      ; show MSG data
;      CONTOUR, wl,NLEVELS=1
      plt,tbamsu,window=0,/realcont,/cont_nofill,title='TB AMSU',/rempli,/nocontour
      goto, detection
   END
   'MSG' : BEGIN
;      name='msg-tb108_2006-08-01_15min.nc'
      path=preject_id_env
      name='msg-tb108_2006-08-13_15min.nc'
      file=path+name
      initncdf, file, xaxisname = 'longitude', yaxisname = 'latitude'
     lon1=-25 & lon2=25 & lat1=-5 & lat2=20
      domdef,lon1,lon2,lat1,lat2
      h1=23 & h2=23   ; en principe, la meme heure que AMSU
      data=read_ncdf('DATA', h1,h2,/timestep,timevar = 'time', file = file)
      ; ++ close
      ; time information
      date=strmid(name,50,50)
      ; +todo+ heure inside data
      wl=smooth(data.arr,10,/edge_truncate,/nan)
      threshold=239.
      s=size(wl,/DIMENSIONS)
      ni=s[0]
      ll=s[1]
      print,ni,ll
      ; show MSG data
     ; CONTOUR, wl,NLEVELS=1
      ind=where(wl gt threshold)
     wl(ind)=0
      plt,wl,window=1,/realcont,/cont_nofill,title='TB MSG',/rempli,/nocontour,min=200
     goto, detection
   END
   'FAKE' : BEGIN
      print,'ginette'
      threshold=0.05
      delta=0.01
      ; build fake data
      name='abcdef_20010203_04:05'
      ni=10
      ll=10
      tb22v=fltarr(ni,ll)+1.
      wl=fltarr(ni,ll)
      ; fake cloud 1
      wl[1,1]=threshold+delta
      wl[1,2]=threshold+delta
      wl[1,3]=threshold+delta
      wl[2,1]=threshold+delta
      wl[2,2]=threshold+delta
      wl[2,3]=threshold+delta
      wl[3,1]=threshold+delta
      wl[3,2]=threshold+delta
      wl[3,3]=threshold+delta
      ; fake cloud 2
      wl[7,7]=threshold*2 + delta
      wl[7,8]=threshold*2 + delta
      wl[8,7]=threshold*2 + delta
      wl[8,8]=threshold*2 + delta
      wv=fltarr(ni,ll)
      us=fltarr(ni,ll)
      ; show fake data
      CONTOUR, wl,NLEVELS=1
      goto, detection
   END
ENDCASE

;extraction des nuages
detection:
ncloud_max=5000
nuag=intarr(ni,ll)
nu=0
FOR j=0,ll-1 DO BEGIN
   ;print, j
   FOR i=0,(ni-1) DO BEGIN
      IF (wl(i,j) gt 0 and wl(i,j) lt threshold) THEN BEGIN
         nuage=nuag((i-1)>0:(i+1)<(ni-1),(j-1)>0:j)
         ind=where(nuage gt 0,nb)
         IF (nb eq 0) THEN BEGIN
            nu=nu+1
            nuag(i,j)=nu
          ENDIF
         IF (nb ne 0) THEN BEGIN
            nuag(i,j)=min(nuage(ind))
            FOR kj=0>(j-1),j DO BEGIN
                FOR ki=0>(i-1),(i+1)<(ni-1) DO BEGIN
                   IF (nuag(ki,kj) ne 0) THEN BEGIN
                      nuag(ki,kj)=nuag(i,j)
                   ENDIF
                ENDFOR
            ENDFOR
         ENDIF
        ; print , 'detection',i,j,nuag(i,j),wl(i,j)
      ENDIF
   ENDFOR
ENDFOR
print,'nb nuages',max(nuag)
;on a numerote les nuages. Recherche des affectations abusives

FOR j=0,ll-1 DO BEGIN
    FOR i=0,(ni-1) DO BEGIN
      IF (nuag(i,j) gt 0) THEN BEGIN
         nu=nuag(i,j)
         cloud=nuag((i-1)>0:(i+1)<(ni-1),(j-1)>0:(j+1)<(ll-1))
         kid=where(cloud eq nu,nbi)
         kdi=where((cloud ne nu) and (cloud ne 0),nbd)
         IF nbd ne 0 THEN BEGIN       
            ind=where(nuag eq nu)
             nuag(ind)=min(cloud(kdi))
         ENDIF
      ENDIF
   ENDFOR
 ENDFOR
numax=max(nuag)

test=where(nuag ne 0)
nuag(test)=nuag(test)+100
;loadct,18
plt,nuag,window=2,/realcont,/cont_nofill,title='nuages MSG',/rempli,/nocontour,min=min(nuag),max=max(nuag)
;Moyennes et ecarts types dans les nuages
compt=intarr(numax)
lmoy=fltarr(numax)
lstd=fltarr(numax)
tbmoy=fltarr(numax)

knu=0
nu=1
labnu:
;ind=where(nuag eq nu,nb)
ind=where((nuag eq nu) and (wl gt 0.),nb)
IF nb ne 0 THEN BEGIN
  compt(knu)=nb  ; nb pixels
  lmoy(knu)=mean(wl(ind))
  tb=tbamsu(ind)
  jnd=where(tb gt 0.,nn)
  if nn ne 0 then tbmoy(knu)=mean(tb(jnd))
print,knu,nb
  IF (nb gt 1) THEN BEGIN
     lstd(knu)=stddev(wl(ind))
  ENDIF
  knu=knu+1
ENDIF
nu=nu+1
IF nu le numax THEN BEGIN
   goto,labnu
ENDIF

IF ( knu gt 0 ) THEN BEGIN
   print,'nb nuages',knu,mean(compt),mean(lmoy),mean(tbmoy)
ENDIF ELSE BEGIN
   print, '0 nuage !',numax
ENDELSE

fullfilename = '/tmp/ssminuage.txt'
openw,11,'/tmp/ssminuage.txt', ERROR = error
IF (error NE 0) then begin
   ras = report(['eee : can not open for writing '$
         + '!C' $
         + fullfilename])
   STOP
ENDIF

printf,11,"# filename :",file
printf,11,"# threshold:",threshold
printf,11,"#"
printf,11,"# Cloud# nb_points lmoy wmoy wstd umoy ustd"
FOR knu=1,numax DO BEGIN
    printf,11,knu,compt(knu-1),lmoy(knu-1),lstd(knu-1),tbmoy(knu-1)
ENDFOR
close,11

end
