% VARAMMA_STARTUP initialisation of matlab/octave environment for VARAMMA project

%+
%
% .. _varamma_startup.m:
%
% =================
% varamma_startup.m
% =================
%
% ---------------------------------------------------------------
% initialisation of matlab/octave environment for VARAMMA project
% ---------------------------------------------------------------
%
% DESCRIPTION
% ===========
%
% Define :
%  - path for matlab/octave commands used in VARAMMA project
%  - IO directories in global variables
%
% This file can be either run classicaly when current directory
% is ${PROJECT}::
%
%  >> varamma_startup
%
%
% If linked or copy to ./startup.m, it will be automaticaly
% run by matlab at start.
%
% If linked or copy to ${HOME}/.octaverc, it will be automaticaly
% run by octave at start.
%
% SEE ALSO
% ========
%
% :ref:`varamma_profile.sh`
%
% TODO
% ====
%
% Minimal version octave : 3.0 still true ?!
%
% intwarning error
%
% intwarning octave
%
% EVOLUTIONS
% ==========
%
% $Id: varamma_startup.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
% - fplod 20110802T142257Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * force GNUTERM to X11 if running octave on MacOS
%
% - fplod 20110520T095918Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * introducing octave version 3.4 (available on cratos)
%
% - fplod 20110503T070338Z 
%
%   * replace VARAMMA by PROJECT
%
% - fplod 20110314T114224Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add global variable VARAMMA to be used in rundemos
%
% - fplod 20110309T111014Z loholt1
%
%   * add 7.10 for matlab (case on matlab in loholt1)
%   * reactivate netcdf detection
%     either netcdf.open is available (case on matlab in loholt1
%     or matlab on jaclod windows) or not (case on matlab and octave on 
%     LOCEAN plateforms
%
% - fplod 20110307T171843Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * no more intwarning when matlab 7.11 is running
%
% - fplod 20110302T105216Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add intwarning when octave 3.2.3 is running (on aedon)
%
% - fplod 20110228T131154Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add intwarning when octave 3.2.4 is running (on cratos)
%
% - fplod 20110217T153835Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * controle of error/warning
%     see http://www.kxcad.net/cae_MATLAB/techdoc/ref/intwarning.html
%     see http://www.gnu.org/software/octave/doc/interpreter/Enabling-and-Disabling-Warnings.html
%
% - fplod 20101022T142723Z zeus.locean-ipsl.upmc.fr (Linux)
%
%   * reactivation of application and application version detection
%
% - fplod 20100726T135206Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix on value of netcdf_available (boolean)
%
% - fplod 20100721T10000Z
%
%   * add utilitaires to path
%
% - fplod 20100712T072903Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add external_matlab to path
%
% - fplod 20100615T150000Z
%
%   * test if nectdf available
%
% - fplod 20100608T123239Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * make application_version useable in functions
%
% - fplod 20100525T095121Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * moved from MSG project to VARAMMA
%
% - fplod 20100503T102901Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
%
%clear all
%
matlab_minimal_version_required = '7.4';
octave_minimal_version_required = '3.0.2';
%
%disp('iii : adding path to PROJECT matlab tools')
%
% test if PROJECT environment set
global PROJECT;
PROJECT=getenv('PROJECT');
%if ( isempty(PROJECT) )
% error('eee : PROJECT environment not set');
%else
% disp(['iii : PROJECT =' PROJECT])
%end
%
% add path
addpath(PROJECT);
%addpath([PROJECT '/src/external_matlab/']);
addpath([PROJECT '/src/utilitaires/']);
%
% IO directories
% test if PROJECT_ID environment set

global PROJECT_ID;
PROJECT_ID=getenv('PROJECT_ID');
%if ( isempty(PROJECT_ID) )
% error('eee : PROJECT_ID environment not set');
%end
%
% test if PROJECT_OD environment set
global PROJECT_OD;
PROJECT_OD=getenv('PROJECT_OD');
%if ( isempty(PROJECT_OD) )
% error('eee : PROJECT_OD environment not set');
%end
%
global application;
global application_version;
%
% detect if either octave or matlab running
if exist('matlabpath','builtin')
 application='matlab';
 tmp=ver(application);
 application_version=tmp.Version;
 clear tmp;
 if verLessThan('matlab', matlab_minimal_version_required)
  disp(['matlab_minimal_version_required = ', matlab_minimal_version_required]);
  disp(['application_version =', application_version]);
  warning('www : you have trouble running an older matlab version');
 end
end
if exist('OCTAVE_VERSION','builtin')
 application='octave';
 application_version=version; %% WARNING : do not add () because of matlab 6
end
%
global netcdf_open_available
netcdf_open=which('netcdf.open');
if (isempty(netcdf_open))
  netcdf_open_available=0;
else
  netcdf_open_available=1;
end
clear netcdf_open
%
% set up terminal
switch application
  case {'matlab'}
  case {'octave'}
       if ismac()
          setenv('GNUTERM','X11');
       end
  otherwise
      error(['unknown application version running ', application , ' ' ,application_version]);
end

% severe warning and errors
switch application
  case {'matlab'}
     switch application_version
        case {'7.4'}
           intwarning('on')
        case {'7.10','7.11'}
             disp([ 'non intwarning when matlab is running']);
        otherwise
           error(['unknown application version running ', application , ' ' ,application_version]);
     end

     s = warning('on', 'MATLAB:intConvertNaN');
     % turn on MATLAB:divideByZero
     s = warning('on', 'MATLAB:divideByZero');
     % show warnings
     %++debug warning('query','all');
     %++debug intwarning('query')
  case {'octave'}
     switch application_version
        case {'3.0.2'}
             disp([ 'non intwarning when octave is running']);
        case {'3.2.3','3.2.4'}
             intwarning('on')
        case {'3.4.0'}
             disp([ 'no more intwarning when octave is running']);
        otherwise
           error(['unknown application version running ', application , ' ' ,application_version]);
     end
     s = warning('on', 'Octave:divideByZero');
     % show warnings
     %++ debug warning('query','all')
     %++ 33 s=warning('query','all')
     %++ 33 s.identifier
     %++ 33 s.state
  otherwise
     error('unknown application running');
end
more on
